@@ -81,7 +81,7 @@ def attachSettings(settingsLocals, backends, preferred, config):
             'dsn': hostInfo.info['SENTRY_DSN'],
         },
         'MIDDLEWARE_CLASSES': \
-            list(settingsLocals.get('MIDDLEWARE_CLASSES', ()) + [
+            list(settingsLocals.get('MIDDLEWARE_CLASSES', ())) + [
             ('raven.contrib.django.raven_compat.middleware.'
              'SentryResponseErrorIdMiddleware'),
         ],
